@@ -6,6 +6,7 @@
  */
 
 #include "kateprojectinfoview.h"
+#include "kateproject.h"
 #include "kateprojectinfoviewcodeanalysis.h"
 #include "kateprojectinfoviewindex.h"
 #include "kateprojectinfoviewnotes.h"
@@ -19,17 +20,19 @@
 KateProjectInfoView::KateProjectInfoView(KateProjectPluginView *pluginView, KateProject *project)
     : m_pluginView(pluginView)
     , m_project(project)
+    , m_terminal(nullptr)
 {
     /**
      * skip terminal toolviews if no terminal aka KonsolePart around
      */
-    if (KateProjectInfoViewTerminal::pluginFactory()) {
+    if (KateProjectInfoViewTerminal::isLoadable()) {
         /**
          * terminal for the directory with the .kateproject file inside
          */
         const QString projectPath = QFileInfo(QFileInfo(m_project->fileName()).path()).canonicalFilePath();
         if (!projectPath.isEmpty()) {
-            addTab(new KateProjectInfoViewTerminal(pluginView, projectPath), i18n("Terminal (.kateproject)"));
+            m_terminal = new KateProjectInfoViewTerminal(pluginView, projectPath);
+            addTab(m_terminal, i18n("Terminal (.kateproject)"));
         }
 
         /**
@@ -76,3 +79,17 @@ bool KateProjectInfoView::ignoreEsc() const
     // else: always hide toolview, nothing to ignore
     return false;
 }
+
+void KateProjectInfoView::resetTerminal(const QString &directory)
+{
+    if (m_terminal) {
+        m_terminal->respawn(directory);
+    }
+}
+
+void KateProjectInfoView::runCmdInTerminal(const QString &workingDir, const QString &cmd)
+{
+    if (auto terminal = qobject_cast<KateProjectInfoViewTerminal *>(currentWidget())) {
+        terminal->runCommand(workingDir, cmd);
+    }
+}
