@@ -12,7 +12,6 @@
 #include <QMenu>
 #include <QPointer>
 #include <QStackedWidget>
-#include <QTimer>
 #include <QToolButton>
 
 #include <KTextEditor/View>
@@ -113,36 +112,11 @@ public:
         return m_plugin;
     }
 
-    /**
-     * @brief Shows diff in a fixed view, i.e., the view is recycled instead
-     * of creating new view every time
-     * @param contents diff contents
-     */
-    void showDiffInFixedView(const QByteArray &contents);
-
-    /**
-     * Same as above with call back for setting a context menu
-     *
-     * @param cb Callback on the view. This should always take KTextEditor::View*
-     * as a parameter. This is mainly used to plug-in context-menu actions.
-     */
-    template<typename ViewCallback>
-    void showDiffInFixedView(const QByteArray &contents, ViewCallback cb)
-    {
-        showDiffInFixedView(contents);
-        cb(m_fixedView.view);
-    }
-
     /**
      * Open terminal view at \p dirPath location for project \p project
      */
     void openTerminal(const QString &dirPath, KateProject *project);
 
-    /**
-     * Returns project base dir for provided url
-     */
-    Q_INVOKABLE QString projectBaseDirForUrl(const QUrl &url);
-
 public Q_SLOTS:
     /**
      * Create views for given project.
@@ -158,6 +132,8 @@ public Q_SLOTS:
      */
     void switchToProject(const QDir &dir);
 
+    void runCmdInTerminal(const QString &workingDir, const QString &cmd);
+
 private Q_SLOTS:
     /**
      * Plugin config updated
@@ -268,13 +244,6 @@ Q_SIGNALS:
      */
     void gotoSymbol(const QString &word, int &results);
 
-    /**
-     * Signal for outgoing message, the host application will handle them!
-     * Will only be handled inside the main windows of this plugin view.
-     * @param message outgoing message we send to the host application
-     */
-    void message(const QVariantMap &message);
-
     /**
      * Signal for location changed. Location gets saved in history
      * of the current KateViewSpace
@@ -325,6 +294,11 @@ private Q_SLOTS:
      */
     void openDirectoryOrProject();
 
+    /**
+     * Open a folder / project
+     */
+    void openDirectoryOrProject(const QDir &dir);
+
     /**
      * Show projects To-Dos and Fix-mes
      */
