@@ -7,8 +7,7 @@
 
 #include "kateprojectview.h"
 #include "branchcheckoutdialog.h"
-#include "filehistorywidget.h"
-#include "git/gitutils.h"
+#include "gitprocess.h"
 #include "gitwidget.h"
 #include "kateprojectfiltermodel.h"
 #include "kateprojectpluginview.h"
@@ -24,7 +23,6 @@
 #include <KLocalizedString>
 
 #include <QPushButton>
-#include <QSortFilterProxyModel>
 #include <QTimer>
 #include <QVBoxLayout>
 
@@ -32,7 +30,6 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
     : m_pluginView(pluginView)
     , m_project(project)
     , m_treeView(new KateProjectViewTree(pluginView, project))
-    , m_stackWidget(new QStackedWidget(this))
     , m_filter(new KLineEdit())
     , m_branchBtn(new QToolButton)
 {
@@ -43,12 +40,10 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
     layout->setSpacing(0);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_branchBtn);
-    layout->addWidget(m_stackWidget);
+    layout->addWidget(m_treeView);
     layout->addWidget(m_filter);
     setLayout(layout);
 
-    m_stackWidget->addWidget(m_treeView);
-
     m_branchBtn->setAutoRaise(true);
     m_branchBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     m_branchBtn->setSizePolicy(QSizePolicy::Minimum, m_branchBtn->sizePolicy().verticalPolicy());
@@ -63,12 +58,18 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
     });
     chckbr->setText(i18n("Checkout Git Branch"));
 
+    m_filterStartTimer.setSingleShot(true);
+    m_filterStartTimer.setInterval(400);
+    m_filterStartTimer.callOnTimeout(this, &KateProjectView::filterTextChanged);
+
     /**
      * setup filter line edit
      */
     m_filter->setPlaceholderText(i18n("Filter..."));
     m_filter->setClearButtonEnabled(true);
-    connect(m_filter, &KLineEdit::textChanged, this, &KateProjectView::filterTextChanged);
+    connect(m_filter, &KLineEdit::textChanged, this, [this] {
+        m_filterStartTimer.start();
+    });
 
     /**
      * Setup git checkout stuff
@@ -77,7 +78,8 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
         BranchCheckoutDialog bd(mainWindow->window(), m_pluginView, m_project->baseDir());
         bd.openDialog();
     });
-    currBranchAct->setIcon(QIcon(QStringLiteral(":/icons/icons/sc-apps-git.svg")));
+    currBranchAct->setIcon(gitIcon());
+    currBranchAct->setToolTip(i18n("Checkout branch"));
     m_branchBtn->setDefaultAction(currBranchAct);
 
     checkAndRefreshGit();
@@ -86,9 +88,6 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
     connect(&m_branchChangedWatcher, &QFileSystemWatcher::fileChanged, this, [this] {
         m_project->reload(true);
     });
-
-    // file history
-    connect(m_treeView, &KateProjectViewTree::showFileHistory, this, &KateProjectView::showFileGitHistory);
 }
 
 KateProjectView::~KateProjectView()
@@ -105,8 +104,9 @@ void KateProjectView::openSelectedDocument()
     m_treeView->openSelectedDocument();
 }
 
-void KateProjectView::filterTextChanged(const QString &filterText)
+void KateProjectView::filterTextChanged()
 {
+    const auto filterText = m_filter->text();
     /**
      * filter
      */
@@ -120,40 +120,9 @@ void KateProjectView::filterTextChanged(const QString &filterText)
     }
 }
 
-void KateProjectView::setTreeViewAsCurrent()
-{
-    Q_ASSERT(m_treeView != m_stackWidget->currentWidget());
-
-    auto currentFileHistory = m_stackWidget->currentWidget();
-    m_stackWidget->removeWidget(currentFileHistory);
-    delete currentFileHistory;
-
-    m_stackWidget->setCurrentWidget(m_treeView);
-}
-
-void KateProjectView::showFileGitHistory(const QString &file)
-{
-    // create on demand and on switch back delete
-    auto fhs = new FileHistoryWidget(file);
-    connect(fhs, &FileHistoryWidget::backClicked, this, &KateProjectView::setTreeViewAsCurrent);
-    connect(fhs, &FileHistoryWidget::commitClicked, this, [this](const QByteArray &diff) {
-        m_pluginView->showDiffInFixedView(diff);
-    });
-    connect(fhs, &FileHistoryWidget::errorMessage, m_pluginView, [this](const QString &s, bool warn) {
-        QVariantMap genericMessage;
-        genericMessage.insert(QStringLiteral("type"), warn ? QStringLiteral("Error") : QStringLiteral("Info"));
-        genericMessage.insert(QStringLiteral("category"), i18n("Git"));
-        genericMessage.insert(QStringLiteral("categoryIcon"), QIcon(QStringLiteral(":/icons/icons/sc-apps-git.svg")));
-        genericMessage.insert(QStringLiteral("text"), s);
-        Q_EMIT m_pluginView->message(genericMessage);
-    });
-    m_stackWidget->addWidget(fhs);
-    m_stackWidget->setCurrentWidget(fhs);
-}
-
 void KateProjectView::checkAndRefreshGit()
 {
-    const auto dotGitPath = GitUtils::getDotGitPath(m_project->baseDir());
+    const auto dotGitPath = getRepoBasePath(m_project->baseDir());
     /**
      * Not in a git repo or git was removed
      */
