@@ -3,7 +3,6 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#include <QMenu>
 
 #include "quickdialog.h"
 
@@ -15,7 +14,6 @@ class StashFilterModel;
 class KActionCollection;
 class QStandardItemModel;
 class QProcess;
-class GitWidget;
 
 namespace KTextEditor
 {
@@ -40,7 +38,7 @@ enum class StashMode : uint8_t {
     ShowStashContent,
 };
 
-class StashDialog : public QuickDialog
+class StashDialog : public HUDDialog
 {
     Q_OBJECT
 public:
@@ -53,19 +51,17 @@ public:
     Q_SIGNAL void showStashDiff(const QByteArray &diff);
 
 protected Q_SLOTS:
-    void slotReturnPressed() override;
+    void slotReturnPressed(const QModelIndex &index) override;
 
 private:
     QProcess *gitp(const QStringList &arguments);
     void stash(bool keepIndex, bool includeUntracked);
     void getStashList();
-    void popStash(const QByteArray &index, const QString &command = QStringLiteral("pop"));
-    void applyStash(const QByteArray &index);
-    void dropStash(const QByteArray &index);
-    void showStash(const QByteArray &index);
+    void popStash(const QString &index, const QString &command = QStringLiteral("pop"));
+    void applyStash(const QString &index);
+    void dropStash(const QString &index);
+    void showStash(const QString &index);
 
-    QStandardItemModel *m_model;
-    StashFilterModel *m_proxyModel;
     QString m_gitPath;
     QString m_projectPath;
     StashMode m_currentMode = StashMode::None;
