@@ -6,17 +6,15 @@
 #include "kateurlbar.h"
 #include "kateapp.h"
 #include "kateviewmanager.h"
+#include "ktexteditor_utils.h"
 
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
-#include <KAcceleratorManager>
-#include <KActionCollection>
 #include <KColorScheme>
 #include <KLocalizedString>
 
 #include <QAbstractListModel>
-#include <QAction>
 #include <QApplication>
 #include <QDir>
 #include <QHBoxLayout>
@@ -575,6 +573,17 @@ public:
         connect(qApp, &QApplication::paletteChanged, this, &BreadCrumbView::updatePalette, Qt::QueuedConnection);
         updatePalette();
 
+        auto onConfigChanged = [this] {
+            KConfigGroup cg(KSharedConfig::openConfig(), "General");
+            auto v = cg.readEntry("Show Symbol In Navigation Bar", true);
+            if (v != m_showSymbolCrumb) {
+                m_showSymbolCrumb = v;
+                Q_EMIT requestRefresh();
+            }
+        };
+        connect(KateApp::self(), &KateApp::configurationChanged, this, onConfigChanged);
+        onConfigChanged();
+
         connect(this, &QListView::clicked, this, &BreadCrumbView::onClicked);
     }
 
@@ -621,6 +630,10 @@ public:
             i++;
         }
 
+        if (!m_showSymbolCrumb) {
+            return;
+        }
+
         auto *mainWindow = m_urlBar->viewManager()->mainWindow();
         QPointer<QObject> lsp = mainWindow->pluginView(QStringLiteral("lspclientplugin"));
         if (lsp) {
@@ -948,9 +961,11 @@ private:
     QPointer<QAbstractItemModel> m_symbolsModel;
     QMetaObject::Connection m_connToView; // Only one conn at a time
     bool m_isNavigating = false;
+    bool m_showSymbolCrumb = true;
 
 Q_SIGNALS:
     void unsetFocus();
+    void requestRefresh();
 };
 
 // TODO: Merge this class back into KateUrlBar
@@ -997,6 +1012,13 @@ public:
         connect(m_mainCrumbView, &BreadCrumbView::unsetFocus, this, [this] {
             m_urlBar->viewManager()->activeView()->setFocus();
         });
+        connect(m_mainCrumbView, &BreadCrumbView::requestRefresh, this, [this] {
+            auto vs = m_urlBar->viewSpace();
+            auto view = vs->currentView();
+            if (vs && view) {
+                setUrl(view->document());
+            }
+        });
 
         connect(
             qApp,
@@ -1021,13 +1043,9 @@ public:
         }
     }
 
-    void setUrl(const QUrl &url)
+    void setUrl(KTextEditor::Document *doc)
     {
-        QObject *project = m_urlBar->viewManager()->mainWindow()->pluginView(QStringLiteral("kateprojectplugin"));
-        QString baseDir;
-        if (project) {
-            QMetaObject::invokeMethod(project, "projectBaseDirForUrl", Q_RETURN_ARG(QString, baseDir), Q_ARG(QUrl, url));
-        }
+        const QString baseDir = Utils::projectBaseDirForDocument(doc);
 
         m_currBaseDir = baseDir;
         if (m_currBaseDir.isEmpty()) {
@@ -1036,7 +1054,7 @@ public:
         } else {
             m_ellipses->show();
         }
-        m_mainCrumbView->setUrl(baseDir, url);
+        m_mainCrumbView->setUrl(baseDir, doc->url());
     }
 
     QPixmap separatorPixmap()
@@ -1122,7 +1140,7 @@ KateUrlBar::KateUrlBar(KateViewSpace *parent)
 
     setupLayout();
 
-    auto *vm = parent->viewManger();
+    auto *vm = parent->viewManager();
     connect(vm, &KateViewManager::viewChanged, this, &KateUrlBar::onViewChanged);
 
     connect(vm, &KateViewManager::showUrlNavBarChanged, this, [this, vm](bool show) {
@@ -1144,7 +1162,7 @@ void KateUrlBar::open()
 
 KateViewManager *KateUrlBar::viewManager()
 {
-    return m_parentViewSpace->viewManger();
+    return m_parentViewSpace->viewManager();
 }
 
 KateViewSpace *KateUrlBar::viewSpace()
@@ -1168,6 +1186,16 @@ void KateUrlBar::setupLayout()
     layout->setContentsMargins({});
     layout->setSpacing(0);
     layout->addWidget(m_stack);
+
+    auto updatePalette = [this]() {
+        auto pal = m_untitledDocLabel->palette();
+        auto textColor = pal.text().color();
+        textColor = textColor.lightness() > 127 ? textColor.darker(150) : textColor.lighter(150);
+        pal.setBrush(QPalette::Active, QPalette::WindowText, textColor);
+        m_untitledDocLabel->setPalette(pal);
+    };
+    updatePalette();
+    connect(qApp, &QApplication::paletteChanged, this, updatePalette, Qt::QueuedConnection);
 }
 
 void KateUrlBar::onViewChanged(KTextEditor::View *v)
@@ -1181,7 +1209,8 @@ void KateUrlBar::onViewChanged(KTextEditor::View *v)
 
     if (!v) {
         updateForDocument(nullptr);
-        m_untitledDocLabel->setText(i18n("Untitled"));
+        // no view => show nothing
+        m_untitledDocLabel->setText({});
         m_stack->setCurrentWidget(m_untitledDocLabel);
         return;
     }
@@ -1218,7 +1247,7 @@ void KateUrlBar::updateForDocument(KTextEditor::Document *doc)
         return;
     }
 
-    m_urlBarView->setUrl(doc->url());
+    m_urlBarView->setUrl(doc);
 }
 
 #include "kateurlbar.moc"
